@@ -1,53 +1,86 @@
-from django.contrib.contenttypes.models import ContentType
-from django.db.models import Q
+from __future__ import unicode_literals
 
-from autocomplete_light.generic import GenericModelChoiceField
+from autocomplete_light.fields import GenericModelChoiceField
+import six
 
+from ..settings import DEFAULT_SEARCH_FIELDS
 from .model import AutocompleteModel
 
 __all__ = ['AutocompleteGeneric']
 
 
-class AutocompleteGeneric(AutocompleteModel):
+class AutocompleteGenericMetaClass(type):
+    def __new__(cls, name, bases, attrs):
+        new_class = super(AutocompleteGenericMetaClass, cls).__new__(cls, name,
+                bases, attrs)
+
+        if attrs.get('__module__',
+                '').startswith('autocomplete_light.autocomplete'):
+            # We are defining one of our own classes.
+            return new_class
+
+        if not new_class.search_fields:
+            default = DEFAULT_SEARCH_FIELDS
+            new_class.search_fields = [default] * len(new_class.choices)
+
+        return new_class
+
+
+class AutocompleteGeneric(six.with_metaclass(AutocompleteGenericMetaClass,
+        AutocompleteModel)):
     """
-    Autocomplete which considers choices as a list of querysets. It inherits
-    from AutocompleteModel so make sure that you've read the docs and
-    docstrings for AutocompleteModel before using this class.
+    :py:class:`~.model.AutocompleteModel` extension which considers choices as
+    a **list of querysets**, and composes a choice value with both the content
+    type pk and the actual model pk.
+
+    .. py:attribute:: choices
+
+        A list of querysets. Example::
+
+            choices = (
+                User.objects.all(),
+                Group.objects.all(),
+            )
+
+    .. py:attribute:: search_fields
 
-    choices
-        A list of querysets.
-    search_fields
         A list of lists of fields to search in, configurable like on
         ModelAdmin.search_fields. The first list of fields will be used for the
-        first queryset in choices and so on.
+        first queryset in choices and so on. Example::
 
-    AutocompleteGeneric inherits from AutocompleteModel and supports
-    `limit_choices` and `split_words` exactly like AutocompleteModel.
+            search_fields = (
+                ('email', '^name'),  # Used for User.objects.all()
+                ('name',)            # User for Group.objects.all()
+            )
 
-    However `order_by` is not supported (yet) in AutocompleteGeneric.
+    AutocompleteGeneric inherits from :py:class:`.model.AutocompleteModel` and
+    supports :py:attr:`~.model.AutocompleteModel.limit_choices` and
+    :py:attr:`~.model.AutocompleteModel.split_words` exactly like
+    AutocompleteModel.
+
+    However :py:attr:`~.model.AutocompleteModel.order_by` is not supported
+    (yet) in AutocompleteGeneric.
     """
     choices = None
     search_fields = None
 
     def choice_value(self, choice):
         """
-        Rely on GenericModelChoiceField to return a string containing the
-        content type id and object id of the result.
-
-        Because this autocomplete is made for that field, and to avoid code
-        duplication.
+        Rely on :py:class:`~autocomplete_light.generic.GenericModelChoiceField`
+        to return a string containing the content type id and object id of the
+        result.
         """
         field = GenericModelChoiceField()
         return field.prepare_value(choice)
 
     def validate_values(self):
         """
-        Ensure that every choice is part of a queryset.
+        Ensure that every choice is part of a queryset in :py:attr:`choices`.
         """
         assert self.choices, 'autocomplete.choices should be a queryset list'
 
         for value in self.values:
-            if not isinstance(value, basestring):
+            if not isinstance(value, six.string_types):
                 return False
 
             try:
@@ -55,6 +88,7 @@ class AutocompleteGeneric(AutocompleteModel):
             except ValueError:
                 return False
 
+            from django.contrib.contenttypes.models import ContentType
             try:
                 content_type = ContentType.objects.get_for_id(content_type_id)
             except ContentType.DoesNotExist:
@@ -80,8 +114,7 @@ class AutocompleteGeneric(AutocompleteModel):
 
     def choices_for_request(self):
         """
-        Propose local results and fill the autocomplete with remote
-        suggestions.
+        Return a list of choices from every queryset in :py:attr:`choices`.
         """
         assert self.choices, 'autocomplete.choices should be a queryset list'
 
@@ -107,12 +140,15 @@ class AutocompleteGeneric(AutocompleteModel):
 
     def choices_for_values(self):
         """
-        Values which are not found in the querysets are ignored.
+        Values which are not found in any querysets of :py:attr:`choices` are
+        ignored.
         """
         values_choices = []
 
         for queryset in self.choices:
-            ctype = ContentType.objects.get_for_model(queryset.model).pk
+            from django.contrib.contenttypes.models import ContentType
+            ctype = ContentType.objects.get_for_model(
+                queryset.model, for_concrete_model=False).pk
 
             try:
                 ids = [x.split('-')[1] for x in self.values
