@@ -1,8 +1,9 @@
 from __future__ import unicode_literals
-import six
 
-from django.utils.encoding import force_text
+import six
 from django.db.models import Q
+from django.utils.encoding import force_text
+from django.db import connection
 
 from ..settings import DEFAULT_SEARCH_FIELDS
 
@@ -10,8 +11,7 @@ __all__ = ('AutocompleteModel', )
 
 
 class AutocompleteModel(object):
-    """
-    Autocomplete which considers choices as a queryset.
+    """Autocomplete which considers choices as a queryset.
 
     .. py:attribute:: choices
 
@@ -39,8 +39,11 @@ class AutocompleteModel(object):
 
     .. py:attribute:: order_by
 
-        If set, it will be used to order choices. It can be a single field name
-        or an iterable (ie. list, tuple).
+        If set, it will be used to order choices in the deck. It can be a
+        single field name or an iterable (ie. list, tuple).
+        However, if AutocompleteModel is instanciated with a list of values,
+        it'll reproduce the ordering of values.
+
     """
     limit_choices = 20
     choices = None
@@ -64,12 +67,36 @@ class AutocompleteModel(object):
         """
         Order choices using :py:attr:`order_by` option if it is set.
         """
+        if isinstance(self.order_by, six.string_types):
+            self.order_by = (self.order_by,)
+
+        if self.values:
+            pk_name = ('id' if not getattr(choices.model._meta, 'pk', None)
+                    else choices.model._meta.pk.column)
+
+            field = '"%s"."%s"' if connection.vendor == 'postgresql' \
+                    else '%s.%s'
+            pk_name = field % (choices.model._meta.db_table, pk_name)
+
+            # Order in the user selection order when self.values is set.
+            clauses = ' '.join(['WHEN %s=\'%s\' THEN %s' % (pk_name, pk, i)
+                for i, pk in enumerate(self.values)])
+            ordering = 'CASE %s ELSE  1000 END' % clauses
+
+            ordering_alias = '_autocomplete_light_ordering_'
+            _order_by = (ordering_alias,)
+            if self.order_by:
+                # safe concatenation of list/tuple
+                # thanks lvh from #python@freenode
+                _order_by = set(_order_by) | set(self.order_by)
+
+            return choices.extra(
+                select={ordering_alias: ordering},
+                order_by=_order_by)
+
         if self.order_by is None:
             return choices
 
-        if isinstance(self.order_by, six.string_types):
-            return choices.order_by(self.order_by)
-
         return choices.order_by(*self.order_by)
 
     def choices_for_values(self):
@@ -79,7 +106,7 @@ class AutocompleteModel(object):
         """
         assert self.choices is not None, 'choices should be a queryset'
         return self.order_choices(self.choices.filter(
-            pk__in=[x for x in self.values if x]))
+            pk__in=[x for x in self.values if x != '']))
 
     def choices_for_request(self):
         """
@@ -89,6 +116,8 @@ class AutocompleteModel(object):
         """
         assert self.choices is not None, 'choices should be a queryset'
         assert self.search_fields, 'autocomplete.search_fields must be set'
+        assert not isinstance(self.search_fields, six.string_types), \
+            'autocomplete.search_fields must not be a string'
         q = self.request.GET.get('q', '')
         exclude = self.request.GET.getlist('exclude')
 
