@@ -1,15 +1,16 @@
 import urllib
+import six
 
 from django import http
-
-try:
-    from django.utils import simplejson as json
-except ImportError:
-    import json
-
+from django.utils.encoding import force_text
 
 from .model import AutocompleteModel
 
+try:
+    import json
+except ImportError:
+    from django.utils import simplejson as json
+
 
 class AutocompleteRestModel(AutocompleteModel):
     widget_js_attributes = {'bootstrap': 'rest_model'}
@@ -66,7 +67,7 @@ class AutocompleteRestModel(AutocompleteModel):
 
     def choices_for_request(self):
         choices = super(AutocompleteRestModel, self).choices_for_request()
-        unicodes = [unicode(choice) for choice in choices]
+        unicodes = [force_text(choice) for choice in choices]
 
         slots = self.limit_choices - len(choices)
 
@@ -75,7 +76,7 @@ class AutocompleteRestModel(AutocompleteModel):
 
             for choice in self.get_remote_choices(slots):
                 # avoid data that's already in local
-                if unicode(choice) in unicodes:
+                if force_text(choice) in unicodes:
                     continue
 
                 choices.append(choice)
@@ -171,7 +172,7 @@ class AutocompleteRestModel(AutocompleteModel):
             model = model_class(**unique_data)
 
         for key, value in data.items():
-            is_string = isinstance(value, basestring)
+            is_string = isinstance(value, six.string_types)
             field = model_class._meta.get_field_by_name(key)[0]
 
             if getattr(field, 'rel', None) and is_string:
