@@ -1,15 +1,13 @@
 from __future__ import unicode_literals
-import six
 
+import six
 from django import forms
 from django.db import models
 from django.db.models.query import QuerySet
-from django import forms
-from django.contrib.contenttypes.generic import GenericForeignKey
-from django.contrib.contenttypes.models import ContentType
 
 from .registry import registry as default_registry
-from .widgets import ChoiceWidget, MultipleChoiceWidget, TextWidget
+from .widgets import ChoiceWidget, MultipleChoiceWidget
+from .exceptions import AutocompleteChoicesMustBeQuerySet
 
 __all__ = ['FieldBase', 'ChoiceField', 'MultipleChoiceField',
     'ModelChoiceField', 'ModelMultipleChoiceField', 'GenericModelChoiceField',
@@ -17,6 +15,10 @@ __all__ = ['FieldBase', 'ChoiceField', 'MultipleChoiceField',
 
 
 class FieldBase(object):
+    default_error_messages = {
+        'invalid': '%(autocomplete)s cannot validate %(value)s',
+    }
+
     def __init__(self, autocomplete=None, registry=None, widget=None,
             widget_js_attributes=None, autocomplete_js_attributes=None,
             extra_context=None, *args, **kwargs):
@@ -30,10 +32,14 @@ class FieldBase(object):
                     autocomplete_js_attributes, extra_context)
         kwargs['widget'] = widget
 
-        parents = super(FieldBase, self).__self_class__.__bases__
-        if ((forms.ModelChoiceField in parents or
-                forms.ModelMultipleChoiceField in parents)
-                and isinstance(self.autocomplete.choices, QuerySet)):
+        # Does the subclass have ModelChoiceField or ModelMultipleChoiceField
+        # as a base class?
+        parents = type(self).__mro__
+        if (forms.ModelChoiceField in parents or
+                forms.ModelMultipleChoiceField in parents):
+
+            if not isinstance(self.autocomplete.choices, QuerySet):
+                raise AutocompleteChoicesMustBeQuerySet(self.autocomplete)
             kwargs['queryset'] = self.autocomplete.choices
 
         super(FieldBase, self).__init__(*args, **kwargs)
@@ -48,9 +54,11 @@ class FieldBase(object):
 
     def validate(self, value):
         """
-        Wrap around Autocomplete.validate_values().
+        Wrap around forms.Field and Autocomplete.validate_values().
+
+        Field.validate_values() handles the required option.
         """
-        super(FieldBase, self).validate(value)
+        forms.Field.validate(self, value)
 
         # FIXME: we might actually want to change the Autocomplete API to
         # support python values instead of raw values, that would probably be
@@ -58,8 +66,12 @@ class FieldBase(object):
         values = self.prepare_value(value)
 
         if value and not self.autocomplete(values=values).validate_values():
-            raise forms.ValidationError('%s cannot validate %s' % (
-                self.autocomplete.__name__, value))
+            error_params = {
+                'autocomplete': self.autocomplete.__name__, 'value': value
+            }
+
+            raise forms.ValidationError(self.error_messages['invalid'],
+                                        code='invalid', params=error_params)
 
 
 class ChoiceField(FieldBase, forms.ChoiceField):
@@ -85,16 +97,30 @@ class MultipleChoiceField(ChoiceField, forms.MultipleChoiceField):
     widget = MultipleChoiceWidget
 
 
-class ModelChoiceField(FieldBase, forms.ModelChoiceField):
+class ModelChoiceFieldBase(FieldBase):
+    def _get_queryset(self):
+        return self._queryset
+
+    def _set_queryset(self, queryset):
+        self._queryset = queryset
+        self.widget.choices = self.choices
+
+        # Also update autocomplete choices
+        self.autocomplete.choices = queryset
+
+    queryset = property(_get_queryset, _set_queryset)
+
+
+class ModelChoiceField(ModelChoiceFieldBase, forms.ModelChoiceField):
     widget = ChoiceWidget
 
 
-class ModelMultipleChoiceField(FieldBase,
+class ModelMultipleChoiceField(ModelChoiceFieldBase,
         forms.ModelMultipleChoiceField):
     widget = MultipleChoiceWidget
 
 
-class GenericModelChoiceField(FieldBase, forms.Field):
+class GenericModelChoiceField(ModelChoiceFieldBase, forms.Field):
     """
     Simple form field that converts strings to models.
     """
@@ -105,19 +131,24 @@ class GenericModelChoiceField(FieldBase, forms.Field):
         Given a model instance as value, with content type id of 3 and pk of 5,
         return such a string '3-5'.
         """
+        from django.contrib.contenttypes.models import ContentType
+
         if isinstance(value, six.string_types):
             # Apparently there's a bug in django, that causes a python value to
             # be passed here. This ONLY happens when in an inline ....
             return value
         elif isinstance(value, models.Model):
-            return '%s-%s' % (ContentType.objects.get_for_model(value).pk,
-                              value.pk)
+            content_type = ContentType.objects.get_for_model(
+                value, for_concrete_model=False)
+            return '%s-%s' % (content_type.pk, value.pk)
 
     def to_python(self, value):
         """
         Given a string like '3-5', return the model of content type id 3 and pk
         5.
         """
+        from django.contrib.contenttypes.models import ContentType
+
         if not value:
             return value
 
