@@ -1,5 +1,15 @@
 from __future__ import unicode_literals
 
+import six
+
+from django.db import models
+from .compat import get_model, import_string
+
+from .exceptions import (AutocompleteArgNotUnderstood,
+                         AutocompleteNotRegistered,
+                         NoGenericAutocompleteRegistered,
+                         NonDjangoModelSubclassException)
+
 """
 The registry module provides tools to maintain a registry of autocompletes.
 
@@ -19,14 +29,6 @@ It looks like this:
 
     Module-level instance of :py:class:`AutocompleteRegistry`.
 """
-import six
-
-from django.db import models
-
-from .autocomplete import AutocompleteModelBase, AutocompleteInterface
-from .exceptions import (AutocompleteNotRegistered,
-                         AutocompleteArgNotUnderstood,
-                         NoGenericAutocompleteRegistered)
 
 try:
     from django.utils.module_loading import autodiscover_modules
@@ -48,10 +50,9 @@ class AutocompleteRegistry(dict):
         :py:class:`~.autocomplete.AutocompleteModelBase`. You can override
         it just before calling autodiscover() in urls.py as such::
 
-            import autocomplete_light
-            autocomplete_light.registry.autocomplete_model_base = \
-                autocomplete_light.AutocompleteModelTemplate
-            autocomplete_light.autodiscover()
+            import autocomplete_light.shortcuts as al
+            al.registry.autocomplete_model_base = al.AutocompleteModelTemplate
+            al.autodiscover()
     """
 
     def __init__(self, autocomplete_model_base=None):
@@ -64,9 +65,6 @@ class AutocompleteRegistry(dict):
         self.default_generic = None
         self.autocomplete_model_base = autocomplete_model_base
 
-        if self.autocomplete_model_base is None:
-            self.autocomplete_model_base = AutocompleteModelBase
-
     def autocomplete_for_model(self, model):
         """
         Return the default autocomplete class for a given model or None.
@@ -132,17 +130,48 @@ class AutocompleteRegistry(dict):
         assert len(args) <= 2, 'register takes at most 2 args'
         assert len(args) > 0, 'register takes at least 1 arg'
 
-        model, autocomplete = self.__class__.extract_args(*args)
+        processed_args = []
 
-        if not model:
+        for arg in args:
+            if isinstance(arg, six.string_types):
+                parts = arg.split('.')
+                if len(parts) == 2:
+                    # if 'app_name.ModelName'
+                    app_label = parts[0]
+                    model_name = parts[-1]
+                    model = get_model(app_label=app_label, model_name=model_name)  # noqa
+                    processed_args.append(model)
+                elif len(parts) > 2:
+                    # if 'full.path.to.Model'
+                    model = import_string(arg)
+                    if not issubclass(model, models.Model):
+                        raise NonDjangoModelSubclassException('%s not is subclass of django Model'  # noqa
+                                                              % model.__name__)
+                    processed_args.append(model)
+                else:
+                    processed_args.append(arg)
+            else:
+                processed_args.append(arg)
+
+        model, autocomplete = self.__class__.extract_args(*processed_args)
+
+        # If calling register(YourBaseAutocomplete, YourModel) then you want
+        # the autocomplete name to be YourModelYourBaseAutocomplete, but if
+        # calling register(YourBaseAutocomplete) then name should be
+        # YourBaseAutocomplete
+        derivate_name = model and autocomplete
+
+        if autocomplete and not model:
             try:
                 model = autocomplete.choices.model
             except AttributeError:
-                pass
+                model = getattr(autocomplete, 'model', None)
 
         if model:
             autocomplete = self._register_model_autocomplete(model,
-                autocomplete, **kwargs)
+                                                             autocomplete,
+                                                             derivate_name,
+                                                             **kwargs)
         else:
             name = kwargs.get('name', autocomplete.__name__)
             autocomplete = type(str(name), (autocomplete,), kwargs)
@@ -151,19 +180,25 @@ class AutocompleteRegistry(dict):
         return autocomplete
 
     def _register_model_autocomplete(self, model, autocomplete=None,
-                                    name=None, **kwargs):
-
+                                     derivate_name=False, name=None, **kwargs):
         if name is not None:
             pass
+
         elif autocomplete is not None:
             if autocomplete.__name__.find(model.__name__) == 0:
-                name = autocomplete.__name__
-            else:
+                derivate_name = False
+
+            if derivate_name:
                 name = '%s%s' % (model.__name__, autocomplete.__name__)
+            else:
+                name = autocomplete.__name__
         else:
             name = '%sAutocomplete' % model.__name__
 
         if autocomplete is None:
+            if self.autocomplete_model_base is None:
+                from .autocomplete.shortcuts import AutocompleteModelBase
+                self.autocomplete_model_base = AutocompleteModelBase
             base = self.autocomplete_model_base
         else:
             base = autocomplete
@@ -212,6 +247,7 @@ class AutocompleteRegistry(dict):
             raise AutocompleteNotRegistered(name, self)
 
     def get_autocomplete_from_arg(self, arg=None):
+        from .autocomplete.base import AutocompleteInterface
         if isinstance(arg, six.string_types):
             return self[arg]
         elif isinstance(arg, type) and issubclass(arg, models.Model):
@@ -253,6 +289,7 @@ def _autodiscover(registry):
             if module_has_submodule(mod, 'autocomplete_light_registry'):
                 raise
 
+
 registry = AutocompleteRegistry()
 
 
@@ -276,9 +313,9 @@ def autodiscover():
     Where autocomplete_light_registry.py contains something like::
 
         from models import City, Country
-        import autocomplete_light
-        autocomplete_light.register(City)
-        autocomplete_light.register(Country)
+        import autocomplete_light.shortcuts as al
+        al.register(City)
+        al.register(Country)
 
     When ``autodiscover()`` imports
     ``cities_light.autocomplete_light_registry``, both ``CityAutocomplete`` and
