@@ -1,16 +1,18 @@
 from __future__ import unicode_literals
 
-import unittest
-
+import autocomplete_light.shortcuts as autocomplete_light  # noqa
+try:
+    from django.db.models import QuerySet
+except:
+    # django < 1.6
+    from django.db.models.query import QuerySet
+from django import forms  # noqa
 from django import http
-from django import forms
-from django.test import TestCase
 from django.contrib.contenttypes.models import ContentType
+from django.test import TestCase
 from six import text_type
 
-from ...example_apps.autocomplete_test_case_app.models import User, Group
-
-import autocomplete_light
+from ...example_apps.autocomplete_test_case_app.models import Group, User
 
 
 def make_get_request(query=''):
@@ -118,7 +120,15 @@ class AutocompleteTestCase(TestCase):
             if valid:
                 data = form.cleaned_data['x']
 
-                self.assertEqual(text_type(data), text_type(test['expected_data']),
-                    'Unexepected data: %s for test %s %s' % (
-                        data, self.__class__.__name__, test)
-                )
+                if isinstance(data, QuerySet):
+                    x = [m.pk for m in data]
+                    y = [m.pk for m in test['expected_data']]
+                    self.assertEqual(x, y,
+                        'Unexepected data: %s for test %s %s' % (
+                            data, self.__class__.__name__, test)
+                    )
+                else:
+                    self.assertEqual(text_type(data), text_type(test['expected_data']),
+                        'Unexepected data: %s for test %s %s' % (
+                            data, self.__class__.__name__, test)
+                    )
