@@ -9,19 +9,12 @@ autocomplete_light_registry
     Renders the autocomplete registry, good for debugging, requires being
     authenticated as superuser.
 """
-
-try:
-    from django.conf.urls import patterns, url
-except ImportError:
-    # Django < 1.5
-    from django.conf.urls.defaults import patterns, url
-
-from django.views.generic.base import TemplateView
+from .compat import url, urls
 
 from .views import AutocompleteView, RegistryView
 
 
-urlpatterns = patterns('',
+urlpatterns = urls([
     url(r'^(?P<autocomplete>[-\w]+)/$',
         AutocompleteView.as_view(),
         name='autocomplete_light_autocomplete'
@@ -30,4 +23,4 @@ urlpatterns = patterns('',
         RegistryView.as_view(),
         name='autocomplete_light_registry'
     ),
-)
+])
