@@ -1,5 +1,10 @@
 from __future__ import unicode_literals
 
+from django import forms
+from django.template.loader import render_to_string
+from django.utils import safestring
+from django.utils.translation import ugettext_lazy as _
+
 """
 The provided widgets are meant to rely on an Autocomplete class.
 
@@ -15,13 +20,12 @@ The choice autocomplete widget renders from autocomplete_light/widget.html
 template.
 """
 
-from django import forms
-from django.forms.util import flatatt
-from django.utils import safestring
-from django.template.loader import render_to_string
-from django.utils.translation import ugettext_lazy as _
 
-from .registry import registry as default_registry
+try:
+    from django.forms.utils import flatatt
+except ImportError:
+    from django.forms.util import flatatt
+
 
 __all__ = ['WidgetBase', 'ChoiceWidget', 'MultipleChoiceWidget', 'TextWidget']
 
@@ -125,8 +129,7 @@ class WidgetBase(object):
     def __init__(self, autocomplete=None, widget_js_attributes=None,
                  autocomplete_js_attributes=None, extra_context=None,
                  registry=None, widget_template=None, widget_attrs=None):
-
-        self.registry = default_registry if registry is None else registry
+        self._registry = registry
         self._autocomplete = None
         self.autocomplete_arg = autocomplete
 
@@ -145,12 +148,22 @@ class WidgetBase(object):
             raise PendingDeprecationWarning('widget_js_attributes are'
                     'deprecated in favor of widget_attrs')
 
+    @property
+    def registry(self):
+        if self._registry is None:
+            from autocomplete_light.registry import registry
+            self._registry = registry
+        return self._registry
+
     def render(self, name, value, attrs=None):
         widget_attrs = self.build_widget_attrs(name)
-        attrs = self.build_attrs(attrs)
-        self.html_id = attrs.pop('id', name)
 
         autocomplete = self.autocomplete(values=value)
+
+        attrs = self.build_attrs(self.attrs, attrs, autocomplete=autocomplete)
+
+        self.html_id = attrs.pop('id', name)
+
         choices = autocomplete.choices_for_values()
         values = [autocomplete.choice_value(c) for c in choices]
 
@@ -169,20 +182,23 @@ class WidgetBase(object):
                 self.widget_template)
         return safestring.mark_safe(render_to_string(template, context))
 
-    def build_attrs(self, extra_attrs=None, **kwargs):
-        self.attrs.update(getattr(self.autocomplete, 'attrs', {}))
-        attrs = super(WidgetBase, self).build_attrs(extra_attrs, **kwargs)
+    def build_attrs(self, attrs, extra_attrs=None,
+                    autocomplete=None, **kwargs):
+        attrs.copy()
+        attrs.update(getattr(autocomplete, 'attrs', {}))
+        attrs = super(WidgetBase, self).build_attrs(
+            attrs, extra_attrs, **kwargs)
 
         if 'class' not in attrs.keys():
             attrs['class'] = ''
 
-        attrs['class'] += ' autocomplete'
+        attrs['class'] += ' autocomplete vTextField'
 
         attrs.setdefault('data-autocomplete-choice-selector', '[data-value]')
         attrs.setdefault('data-autocomplete-url',
                          self.autocomplete().get_absolute_url())
         attrs.setdefault('placeholder', _(
-            'type some text to search in this autocomplete').capitalize())
+            'type some text to search in this autocomplete'))
 
         # for backward compatibility
         for key, value in self.autocomplete_js_attributes.items():
@@ -287,12 +303,19 @@ class TextWidget(WidgetBase, forms.TextInput):
 
     def render(self, name, value, attrs=None):
         """ Proxy Django's TextInput.render() """
+
+        autocomplete = self.autocomplete(values=value)
+        attrs = self.build_attrs(self.attrs, attrs, autocomplete=autocomplete)
+
         return forms.TextInput.render(self, name, value, attrs)
 
-    def build_attrs(self, extra_attrs=None, **kwargs):
-        attrs = super(TextWidget, self).build_widget_attrs()
+    def build_attrs(self, attrs, extra_attrs=None,
+                    autocomplete=None, **kwargs):
+        attrs.copy()
+        attrs.update(super(TextWidget, self).build_widget_attrs())
+        attrs.update(getattr(autocomplete, 'attrs', {}))
         attrs.update(super(TextWidget, self).build_attrs(
-            extra_attrs, **kwargs))
+            self.attrs, extra_attrs, **kwargs))
 
         def update_attrs(source, prefix=''):
             for key, value in source.items():
